---
name: Pull request template
about: Contribute to intake-esm with a pull request
title: ''
labels: ''
assignees: ''

---

<!--
Thanks for submitting a PR, your contribution is really appreciated!
Below are a few things we ask you kindly to self-check before getting a review. Remove checks that are not relevant.
-->

Checklist

- [ ] Enable and install [pre-commit](https://pre-commit.com/) to ensure style-guides and code checks are followed.
- [ ] Include documentation when adding new features.
- [ ] Include new tests or update existing tests when applicable.

<!--
Please note any issues this fixes using [closing keywords]( https://help.github.com/articles/closing-issues-using-keywords/ ):
-->

<!--
Please add any other relevant info below:
-->
